/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataplexEntryTypeConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description of the EntryType.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#description DataplexEntryType#description}
    */
    readonly description?: string;
    /**
    * User friendly display name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#display_name DataplexEntryType#display_name}
    */
    readonly displayName?: string;
    /**
    * The entry type id of the entry type.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#entry_type_id DataplexEntryType#entry_type_id}
    */
    readonly entryTypeId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#id DataplexEntryType#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-defined labels for the EntryType.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#labels DataplexEntryType#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location where entry type will be created in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#location DataplexEntryType#location}
    */
    readonly location?: string;
    /**
    * The platform that Entries of this type belongs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#platform DataplexEntryType#platform}
    */
    readonly platform?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#project DataplexEntryType#project}
    */
    readonly project?: string;
    /**
    * The system that Entries of this type belongs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#system DataplexEntryType#system}
    */
    readonly systemAttribute?: string;
    /**
    * Indicates the class this Entry Type belongs to, for example, TABLE, DATABASE, MODEL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#type_aliases DataplexEntryType#type_aliases}
    */
    readonly typeAliases?: string[];
    /**
    * required_aspects block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#required_aspects DataplexEntryType#required_aspects}
    */
    readonly requiredAspects?: DataplexEntryTypeRequiredAspects[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#timeouts DataplexEntryType#timeouts}
    */
    readonly timeouts?: DataplexEntryTypeTimeouts;
}
export interface DataplexEntryTypeRequiredAspects {
    /**
    * Required aspect type for the entry type.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#type DataplexEntryType#type}
    */
    readonly type?: string;
}
export declare function dataplexEntryTypeRequiredAspectsToTerraform(struct?: DataplexEntryTypeRequiredAspects | cdktf.IResolvable): any;
export declare function dataplexEntryTypeRequiredAspectsToHclTerraform(struct?: DataplexEntryTypeRequiredAspects | cdktf.IResolvable): any;
export declare class DataplexEntryTypeRequiredAspectsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexEntryTypeRequiredAspects | cdktf.IResolvable | undefined;
    set internalValue(value: DataplexEntryTypeRequiredAspects | cdktf.IResolvable | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class DataplexEntryTypeRequiredAspectsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataplexEntryTypeRequiredAspects[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexEntryTypeRequiredAspectsOutputReference;
}
export interface DataplexEntryTypeTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#create DataplexEntryType#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#delete DataplexEntryType#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#update DataplexEntryType#update}
    */
    readonly update?: string;
}
export declare function dataplexEntryTypeTimeoutsToTerraform(struct?: DataplexEntryTypeTimeouts | cdktf.IResolvable): any;
export declare function dataplexEntryTypeTimeoutsToHclTerraform(struct?: DataplexEntryTypeTimeouts | cdktf.IResolvable): any;
export declare class DataplexEntryTypeTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexEntryTypeTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataplexEntryTypeTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type google_dataplex_entry_type}
*/
export declare class DataplexEntryType extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataplex_entry_type";
    /**
    * Generates CDKTF code for importing a DataplexEntryType resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataplexEntryType to import
    * @param importFromId The id of the existing DataplexEntryType that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataplexEntryType to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dataplex_entry_type google_dataplex_entry_type} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataplexEntryTypeConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataplexEntryTypeConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _entryTypeId?;
    get entryTypeId(): string;
    set entryTypeId(value: string);
    resetEntryTypeId(): void;
    get entryTypeIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    private _platform?;
    get platform(): string;
    set platform(value: string);
    resetPlatform(): void;
    get platformInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _system?;
    get systemAttribute(): string;
    set systemAttribute(value: string);
    resetSystemAttribute(): void;
    get systemAttributeInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _typeAliases?;
    get typeAliases(): string[];
    set typeAliases(value: string[]);
    resetTypeAliases(): void;
    get typeAliasesInput(): string[] | undefined;
    get uid(): string;
    get updateTime(): string;
    private _requiredAspects;
    get requiredAspects(): DataplexEntryTypeRequiredAspectsList;
    putRequiredAspects(value: DataplexEntryTypeRequiredAspects[] | cdktf.IResolvable): void;
    resetRequiredAspects(): void;
    get requiredAspectsInput(): cdktf.IResolvable | DataplexEntryTypeRequiredAspects[] | undefined;
    private _timeouts;
    get timeouts(): DataplexEntryTypeTimeoutsOutputReference;
    putTimeouts(value: DataplexEntryTypeTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataplexEntryTypeTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
