/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DnsResponsePolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * The description of the response policy, such as 'My new response policy'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#description DnsResponsePolicy#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#id DnsResponsePolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#project DnsResponsePolicy#project}
    */
    readonly project?: string;
    /**
    * The user assigned name for this Response Policy, such as 'myresponsepolicy'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#response_policy_name DnsResponsePolicy#response_policy_name}
    */
    readonly responsePolicyName: string;
    /**
    * gke_clusters block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#gke_clusters DnsResponsePolicy#gke_clusters}
    */
    readonly gkeClusters?: DnsResponsePolicyGkeClusters[] | cdktf.IResolvable;
    /**
    * networks block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#networks DnsResponsePolicy#networks}
    */
    readonly networks?: DnsResponsePolicyNetworks[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#timeouts DnsResponsePolicy#timeouts}
    */
    readonly timeouts?: DnsResponsePolicyTimeouts;
}
export interface DnsResponsePolicyGkeClusters {
    /**
    * The resource name of the cluster to bind this ManagedZone to.
    * This should be specified in the format like
    * 'projects/* /locations/* /clusters/*'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#gke_cluster_name DnsResponsePolicy#gke_cluster_name}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly gkeClusterName: string;
}
export declare function dnsResponsePolicyGkeClustersToTerraform(struct?: DnsResponsePolicyGkeClusters | cdktf.IResolvable): any;
export declare function dnsResponsePolicyGkeClustersToHclTerraform(struct?: DnsResponsePolicyGkeClusters | cdktf.IResolvable): any;
export declare class DnsResponsePolicyGkeClustersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DnsResponsePolicyGkeClusters | cdktf.IResolvable | undefined;
    set internalValue(value: DnsResponsePolicyGkeClusters | cdktf.IResolvable | undefined);
    private _gkeClusterName?;
    get gkeClusterName(): string;
    set gkeClusterName(value: string);
    get gkeClusterNameInput(): string | undefined;
}
export declare class DnsResponsePolicyGkeClustersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DnsResponsePolicyGkeClusters[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DnsResponsePolicyGkeClustersOutputReference;
}
export interface DnsResponsePolicyNetworks {
    /**
    * The fully qualified URL of the VPC network to bind to.
    * This should be formatted like
    * 'https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#network_url DnsResponsePolicy#network_url}
    */
    readonly networkUrl: string;
}
export declare function dnsResponsePolicyNetworksToTerraform(struct?: DnsResponsePolicyNetworks | cdktf.IResolvable): any;
export declare function dnsResponsePolicyNetworksToHclTerraform(struct?: DnsResponsePolicyNetworks | cdktf.IResolvable): any;
export declare class DnsResponsePolicyNetworksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DnsResponsePolicyNetworks | cdktf.IResolvable | undefined;
    set internalValue(value: DnsResponsePolicyNetworks | cdktf.IResolvable | undefined);
    private _networkUrl?;
    get networkUrl(): string;
    set networkUrl(value: string);
    get networkUrlInput(): string | undefined;
}
export declare class DnsResponsePolicyNetworksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DnsResponsePolicyNetworks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DnsResponsePolicyNetworksOutputReference;
}
export interface DnsResponsePolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#create DnsResponsePolicy#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#delete DnsResponsePolicy#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#update DnsResponsePolicy#update}
    */
    readonly update?: string;
}
export declare function dnsResponsePolicyTimeoutsToTerraform(struct?: DnsResponsePolicyTimeouts | cdktf.IResolvable): any;
export declare function dnsResponsePolicyTimeoutsToHclTerraform(struct?: DnsResponsePolicyTimeouts | cdktf.IResolvable): any;
export declare class DnsResponsePolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DnsResponsePolicyTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DnsResponsePolicyTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy google_dns_response_policy}
*/
export declare class DnsResponsePolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dns_response_policy";
    /**
    * Generates CDKTF code for importing a DnsResponsePolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DnsResponsePolicy to import
    * @param importFromId The id of the existing DnsResponsePolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DnsResponsePolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/dns_response_policy google_dns_response_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DnsResponsePolicyConfig
    */
    constructor(scope: Construct, id: string, config: DnsResponsePolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _responsePolicyName?;
    get responsePolicyName(): string;
    set responsePolicyName(value: string);
    get responsePolicyNameInput(): string | undefined;
    private _gkeClusters;
    get gkeClusters(): DnsResponsePolicyGkeClustersList;
    putGkeClusters(value: DnsResponsePolicyGkeClusters[] | cdktf.IResolvable): void;
    resetGkeClusters(): void;
    get gkeClustersInput(): cdktf.IResolvable | DnsResponsePolicyGkeClusters[] | undefined;
    private _networks;
    get networks(): DnsResponsePolicyNetworksList;
    putNetworks(value: DnsResponsePolicyNetworks[] | cdktf.IResolvable): void;
    resetNetworks(): void;
    get networksInput(): cdktf.IResolvable | DnsResponsePolicyNetworks[] | undefined;
    private _timeouts;
    get timeouts(): DnsResponsePolicyTimeoutsOutputReference;
    putTimeouts(value: DnsResponsePolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DnsResponsePolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
