/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FirebaseAppCheckDebugTokenConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of a
    * [Web App](https://firebase.google.com/docs/reference/firebase-management/rest/v1beta1/projects.webApps#WebApp.FIELDS.app_id),
    * [Apple App](https://firebase.google.com/docs/reference/firebase-management/rest/v1beta1/projects.iosApps#IosApp.FIELDS.app_id),
    * or [Android App](https://firebase.google.com/docs/reference/firebase-management/rest/v1beta1/projects.androidApps#AndroidApp.FIELDS.app_id)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#app_id FirebaseAppCheckDebugToken#app_id}
    */
    readonly appId: string;
    /**
    * A human readable display name used to identify this debug token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#display_name FirebaseAppCheckDebugToken#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#id FirebaseAppCheckDebugToken#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#project FirebaseAppCheckDebugToken#project}
    */
    readonly project?: string;
    /**
    * The secret token itself. Must be provided during creation, and must be a UUID4,
    * case insensitive. You may use a method of your choice such as random/random_uuid
    * to generate the token.
    *
    * This field is immutable once set, and cannot be updated. You can, however, delete
    * this debug token to revoke it.
    *
    * For security reasons, this field will never be populated in any response.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#token FirebaseAppCheckDebugToken#token}
    */
    readonly token: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#timeouts FirebaseAppCheckDebugToken#timeouts}
    */
    readonly timeouts?: FirebaseAppCheckDebugTokenTimeouts;
}
export interface FirebaseAppCheckDebugTokenTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#create FirebaseAppCheckDebugToken#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#delete FirebaseAppCheckDebugToken#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#update FirebaseAppCheckDebugToken#update}
    */
    readonly update?: string;
}
export declare function firebaseAppCheckDebugTokenTimeoutsToTerraform(struct?: FirebaseAppCheckDebugTokenTimeouts | cdktf.IResolvable): any;
export declare function firebaseAppCheckDebugTokenTimeoutsToHclTerraform(struct?: FirebaseAppCheckDebugTokenTimeouts | cdktf.IResolvable): any;
export declare class FirebaseAppCheckDebugTokenTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FirebaseAppCheckDebugTokenTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: FirebaseAppCheckDebugTokenTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token google_firebase_app_check_debug_token}
*/
export declare class FirebaseAppCheckDebugToken extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_firebase_app_check_debug_token";
    /**
    * Generates CDKTF code for importing a FirebaseAppCheckDebugToken resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the FirebaseAppCheckDebugToken to import
    * @param importFromId The id of the existing FirebaseAppCheckDebugToken that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the FirebaseAppCheckDebugToken to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/firebase_app_check_debug_token google_firebase_app_check_debug_token} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FirebaseAppCheckDebugTokenConfig
    */
    constructor(scope: Construct, id: string, config: FirebaseAppCheckDebugTokenConfig);
    private _appId?;
    get appId(): string;
    set appId(value: string);
    get appIdInput(): string | undefined;
    get debugTokenId(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _token?;
    get token(): string;
    set token(value: string);
    get tokenInput(): string | undefined;
    private _timeouts;
    get timeouts(): FirebaseAppCheckDebugTokenTimeoutsOutputReference;
    putTimeouts(value: FirebaseAppCheckDebugTokenTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | FirebaseAppCheckDebugTokenTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
