/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface KmsCryptoKeyVersionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the cryptoKey associated with the CryptoKeyVersions.
    * Format: ''projects/{{project}}/locations/{{location}}/keyRings/{{keyring}}/cryptoKeys/{{cryptoKey}}''
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#crypto_key KmsCryptoKeyVersion#crypto_key}
    */
    readonly cryptoKey: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#id KmsCryptoKeyVersion#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The current state of the CryptoKeyVersion. Possible values: ["PENDING_GENERATION", "ENABLED", "DISABLED", "DESTROYED", "DESTROY_SCHEDULED", "PENDING_IMPORT", "IMPORT_FAILED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#state KmsCryptoKeyVersion#state}
    */
    readonly state?: string;
    /**
    * external_protection_level_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#external_protection_level_options KmsCryptoKeyVersion#external_protection_level_options}
    */
    readonly externalProtectionLevelOptions?: KmsCryptoKeyVersionExternalProtectionLevelOptions;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#timeouts KmsCryptoKeyVersion#timeouts}
    */
    readonly timeouts?: KmsCryptoKeyVersionTimeouts;
}
export interface KmsCryptoKeyVersionAttestationCertChains {
}
export declare function kmsCryptoKeyVersionAttestationCertChainsToTerraform(struct?: KmsCryptoKeyVersionAttestationCertChains): any;
export declare function kmsCryptoKeyVersionAttestationCertChainsToHclTerraform(struct?: KmsCryptoKeyVersionAttestationCertChains): any;
export declare class KmsCryptoKeyVersionAttestationCertChainsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): KmsCryptoKeyVersionAttestationCertChains | undefined;
    set internalValue(value: KmsCryptoKeyVersionAttestationCertChains | undefined);
    get caviumCerts(): string[];
    get googleCardCerts(): string[];
    get googlePartitionCerts(): string[];
}
export declare class KmsCryptoKeyVersionAttestationCertChainsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): KmsCryptoKeyVersionAttestationCertChainsOutputReference;
}
export interface KmsCryptoKeyVersionAttestationExternalProtectionLevelOptions {
}
export declare function kmsCryptoKeyVersionAttestationExternalProtectionLevelOptionsToTerraform(struct?: KmsCryptoKeyVersionAttestationExternalProtectionLevelOptions): any;
export declare function kmsCryptoKeyVersionAttestationExternalProtectionLevelOptionsToHclTerraform(struct?: KmsCryptoKeyVersionAttestationExternalProtectionLevelOptions): any;
export declare class KmsCryptoKeyVersionAttestationExternalProtectionLevelOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): KmsCryptoKeyVersionAttestationExternalProtectionLevelOptions | undefined;
    set internalValue(value: KmsCryptoKeyVersionAttestationExternalProtectionLevelOptions | undefined);
    get ekmConnectionKeyPath(): string;
    get externalKeyUri(): string;
}
export declare class KmsCryptoKeyVersionAttestationExternalProtectionLevelOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): KmsCryptoKeyVersionAttestationExternalProtectionLevelOptionsOutputReference;
}
export interface KmsCryptoKeyVersionAttestation {
}
export declare function kmsCryptoKeyVersionAttestationToTerraform(struct?: KmsCryptoKeyVersionAttestation): any;
export declare function kmsCryptoKeyVersionAttestationToHclTerraform(struct?: KmsCryptoKeyVersionAttestation): any;
export declare class KmsCryptoKeyVersionAttestationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): KmsCryptoKeyVersionAttestation | undefined;
    set internalValue(value: KmsCryptoKeyVersionAttestation | undefined);
    private _certChains;
    get certChains(): KmsCryptoKeyVersionAttestationCertChainsList;
    get content(): string;
    private _externalProtectionLevelOptions;
    get externalProtectionLevelOptions(): KmsCryptoKeyVersionAttestationExternalProtectionLevelOptionsList;
    get format(): string;
}
export declare class KmsCryptoKeyVersionAttestationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): KmsCryptoKeyVersionAttestationOutputReference;
}
export interface KmsCryptoKeyVersionExternalProtectionLevelOptions {
    /**
    * The path to the external key material on the EKM when using EkmConnection e.g., "v0/my/key". Set this field instead of externalKeyUri when using an EkmConnection.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#ekm_connection_key_path KmsCryptoKeyVersion#ekm_connection_key_path}
    */
    readonly ekmConnectionKeyPath?: string;
    /**
    * The URI for an external resource that this CryptoKeyVersion represents.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#external_key_uri KmsCryptoKeyVersion#external_key_uri}
    */
    readonly externalKeyUri?: string;
}
export declare function kmsCryptoKeyVersionExternalProtectionLevelOptionsToTerraform(struct?: KmsCryptoKeyVersionExternalProtectionLevelOptionsOutputReference | KmsCryptoKeyVersionExternalProtectionLevelOptions): any;
export declare function kmsCryptoKeyVersionExternalProtectionLevelOptionsToHclTerraform(struct?: KmsCryptoKeyVersionExternalProtectionLevelOptionsOutputReference | KmsCryptoKeyVersionExternalProtectionLevelOptions): any;
export declare class KmsCryptoKeyVersionExternalProtectionLevelOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): KmsCryptoKeyVersionExternalProtectionLevelOptions | undefined;
    set internalValue(value: KmsCryptoKeyVersionExternalProtectionLevelOptions | undefined);
    private _ekmConnectionKeyPath?;
    get ekmConnectionKeyPath(): string;
    set ekmConnectionKeyPath(value: string);
    resetEkmConnectionKeyPath(): void;
    get ekmConnectionKeyPathInput(): string | undefined;
    private _externalKeyUri?;
    get externalKeyUri(): string;
    set externalKeyUri(value: string);
    resetExternalKeyUri(): void;
    get externalKeyUriInput(): string | undefined;
}
export interface KmsCryptoKeyVersionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#create KmsCryptoKeyVersion#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#delete KmsCryptoKeyVersion#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#update KmsCryptoKeyVersion#update}
    */
    readonly update?: string;
}
export declare function kmsCryptoKeyVersionTimeoutsToTerraform(struct?: KmsCryptoKeyVersionTimeouts | cdktf.IResolvable): any;
export declare function kmsCryptoKeyVersionTimeoutsToHclTerraform(struct?: KmsCryptoKeyVersionTimeouts | cdktf.IResolvable): any;
export declare class KmsCryptoKeyVersionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): KmsCryptoKeyVersionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: KmsCryptoKeyVersionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version google_kms_crypto_key_version}
*/
export declare class KmsCryptoKeyVersion extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_kms_crypto_key_version";
    /**
    * Generates CDKTF code for importing a KmsCryptoKeyVersion resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the KmsCryptoKeyVersion to import
    * @param importFromId The id of the existing KmsCryptoKeyVersion that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the KmsCryptoKeyVersion to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.36.0/docs/resources/kms_crypto_key_version google_kms_crypto_key_version} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options KmsCryptoKeyVersionConfig
    */
    constructor(scope: Construct, id: string, config: KmsCryptoKeyVersionConfig);
    get algorithm(): string;
    private _attestation;
    get attestation(): KmsCryptoKeyVersionAttestationList;
    private _cryptoKey?;
    get cryptoKey(): string;
    set cryptoKey(value: string);
    get cryptoKeyInput(): string | undefined;
    get generateTime(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    get protectionLevel(): string;
    private _state?;
    get state(): string;
    set state(value: string);
    resetState(): void;
    get stateInput(): string | undefined;
    private _externalProtectionLevelOptions;
    get externalProtectionLevelOptions(): KmsCryptoKeyVersionExternalProtectionLevelOptionsOutputReference;
    putExternalProtectionLevelOptions(value: KmsCryptoKeyVersionExternalProtectionLevelOptions): void;
    resetExternalProtectionLevelOptions(): void;
    get externalProtectionLevelOptionsInput(): KmsCryptoKeyVersionExternalProtectionLevelOptions | undefined;
    private _timeouts;
    get timeouts(): KmsCryptoKeyVersionTimeoutsOutputReference;
    putTimeouts(value: KmsCryptoKeyVersionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | KmsCryptoKeyVersionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
